@@ -22,13 +22,12 @@
 #include "testcalendarobserver.h"
 #include "filestorage.h"
 #include "calendar.h"
-#include <memorycalendar.h>
+#include "memorycalendar.h"
 
-#include <qdebug.h>
+#include <QSignalSpy>
+#include <QTest>
+#include <QTimeZone>
 
-
-#include <qtest.h>
-#include <qsignalspy.h>
 QTEST_MAIN(CalendarObserverTest)
 
 using namespace KCalCore;
@@ -44,7 +43,8 @@ public:
         , mCal(cal)
     {
     }
-    Calendar *mCal;
+
+    Calendar *mCal = nullptr;
 Q_SIGNALS:
     void incidenceAdded(const KCalCore::Incidence::Ptr &incidence);
     void incidenceChanged(const KCalCore::Incidence::Ptr &incidence);
@@ -52,21 +52,30 @@ Q_SIGNALS:
     void incidenceDeletedDeprecated(const KCalCore::Incidence::Ptr &incidence);
     void incidenceDeleted(const KCalCore::Incidence::Ptr &incidence, const Calendar *calendar);
 protected:
-    void calendarIncidenceAdded(const KCalCore::Incidence::Ptr &incidence) override {
+    void calendarIncidenceAdded(const KCalCore::Incidence::Ptr &incidence) override
+    {
         Q_EMIT incidenceAdded(incidence);
     }
-    void calendarIncidenceChanged(const KCalCore::Incidence::Ptr &incidence) override {
+
+    void calendarIncidenceChanged(const KCalCore::Incidence::Ptr &incidence) override
+    {
         Q_EMIT incidenceChanged(incidence);
     }
-    void calendarIncidenceAboutToBeDeleted(const KCalCore::Incidence::Ptr &incidence) override {
+
+    void calendarIncidenceAboutToBeDeleted(const KCalCore::Incidence::Ptr &incidence) override
+    {
         QVERIFY(mCal->incidences().contains(incidence));
         Q_EMIT incidenceAboutToBeDeleted(incidence);
     }
-    void calendarIncidenceDeleted(const KCalCore::Incidence::Ptr &incidence) override {
+
+    void calendarIncidenceDeleted(const KCalCore::Incidence::Ptr &incidence) override
+    {
         QVERIFY(!mCal->incidences().contains(incidence));
         Q_EMIT incidenceDeletedDeprecated(incidence);
     }
-    void calendarIncidenceDeleted(const KCalCore::Incidence::Ptr &incidence, const Calendar *calendar) override {
+
+    void calendarIncidenceDeleted(const KCalCore::Incidence::Ptr &incidence, const Calendar *calendar) override
+    {
         QCOMPARE(calendar, mCal);
         QVERIFY(!calendar->incidences().contains(incidence));
         Q_EMIT incidenceDeleted(incidence, calendar);
@@ -76,7 +85,7 @@ protected:
 void CalendarObserverTest::testAdd()
 {
     qRegisterMetaType<KCalCore::Incidence::Ptr>();
-    MemoryCalendar::Ptr cal(new MemoryCalendar(KDateTime::UTC));
+    MemoryCalendar::Ptr cal(new MemoryCalendar(QTimeZone::utc()));
     SimpleObserver ob(cal.data());
     QSignalSpy spy(&ob, &SimpleObserver::incidenceAdded);
     cal->registerObserver(&ob);
@@ -92,7 +101,7 @@ void CalendarObserverTest::testAdd()
 void CalendarObserverTest::testChange()
 {
     qRegisterMetaType<KCalCore::Incidence::Ptr>();
-    MemoryCalendar::Ptr cal(new MemoryCalendar(KDateTime::UTC));
+    MemoryCalendar::Ptr cal(new MemoryCalendar(QTimeZone::utc()));
     SimpleObserver ob(cal.data());
     QSignalSpy spy(&ob, &SimpleObserver::incidenceChanged);
     cal->registerObserver(&ob);
@@ -111,7 +120,7 @@ void CalendarObserverTest::testDelete()
 {
     qRegisterMetaType<KCalCore::Incidence::Ptr>();
     qRegisterMetaType<const Calendar *>();
-    MemoryCalendar::Ptr cal(new MemoryCalendar(KDateTime::UTC));
+    MemoryCalendar::Ptr cal(new MemoryCalendar(QTimeZone::utc()));
     SimpleObserver ob(cal.data());
     QSignalSpy spy1(&ob, &SimpleObserver::incidenceAboutToBeDeleted);
     QSignalSpy spy2(&ob, &SimpleObserver::incidenceDeleted);
@@ -136,4 +145,5 @@ void CalendarObserverTest::testDelete()
     arguments = spy3.takeFirst();
     QCOMPARE(arguments.at(0).value<KCalCore::Incidence::Ptr>(), static_cast<KCalCore::Incidence::Ptr>(event1));
 }
+
 #include "testcalendarobserver.moc"
